@@ -16,9 +16,11 @@ from dbt_cloud.command import (
     DbtCloudRunListCommand,
     DbtCloudRunCancelCommand,
     DbtCloudJobListCommand,
+    DbtCloudProjectGetCommand,
     DbtCloudProjectListCommand,
     DbtCloudEnvironmentListCommand,
     DbtCloudAccountListCommand,
+    DbtCloudAccountGetCommand,
     DbtCloudAuditLogGetCommand,
 )
 from dbt_cloud.demo import data_catalog
@@ -317,6 +319,13 @@ def get_artifact(file, **kwargs):
     response.raise_for_status()
 
 
+@project.command(help=DbtCloudProjectGetCommand.get_description())
+@DbtCloudProjectGetCommand.click_options
+def get(**kwargs):
+    command = DbtCloudProjectGetCommand.from_click_options(**kwargs)
+    response = execute_and_print(command)
+
+
 @project.command(help=DbtCloudProjectListCommand.get_description())
 @DbtCloudProjectListCommand.click_options
 def list(**kwargs):
@@ -338,6 +347,13 @@ def list(**kwargs):
     response = execute_and_print(command)
 
 
+@account.command(help=DbtCloudAccountGetCommand.get_description())
+@DbtCloudAccountGetCommand.click_options
+def get(**kwargs):
+    command = DbtCloudAccountGetCommand.from_click_options(**kwargs)
+    response = execute_and_print(command)
+
+
 @audit_log.command(help=DbtCloudAuditLogGetCommand.get_description())
 @DbtCloudAuditLogGetCommand.click_options
 def get(**kwargs):
